#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from dataclasses import dataclass, field as _field
from functools import partial
from ...config import custom_scalars, datetime
from numbers import Number
from typing import Any, AsyncGenerator, Dict, List, Generator, Optional

from dataclasses_json import DataClassJsonMixin, config

from ..input.document_category_input import DocumentCategoryInput
from ..input.property_type_input import PropertyTypeInput
from ..input.survey_template_category_input import SurveyTemplateCategoryInput


@dataclass(frozen=True)
class AddLocationTypeInput(DataClassJsonMixin):
    name: str
    documentCategories: List[DocumentCategoryInput]
    properties: List[PropertyTypeInput]
    surveyTemplateCategories: List[SurveyTemplateCategoryInput]
    mapType: Optional[str] = None
    mapZoomLevel: Optional[int] = None
    isSite: Optional[bool] = None
